#============================================
# HTTP Server Plugin Functions
#============================================

#
# Print a usage message
#
def usage(msg = ''):
  if msg != '': print "ERROR: "+msg

  if command == 'generatePlugin':
    print """
    generatePlugin <dmgrRoot> <cellName> <nodeName> <webServerName>
      args:
        <dmgrRoot> Profile directory for the Deployment Manager (no trailing slash)
        <cellName> Cell name for the cell containing the web server being configured
        <nodeName> Node name for the node containing the web server being configured
        <webServerName> Server name for the web server being configured
    """
  elif command == 'propagatePlugin':
    print """
    propagatePlugin <dmgrRoot> <cellName> <nodeName> <webServerName>
      args:
        <dmgrRoot> Profile directory for the Deployment Manager (no trailing slash)
        <cellName> Cell name for the cell containing the web server being configured
        <nodeName> Node name for the node containing the web server being configured
        <webServerName> Server name for the web server being configured
    """
  elif command == 'setDmgrPluginTrace':
    print """
    setDmgrPluginTrace <no Args>  (assumes to set the runtime plugin trace to the Dmgr for the Cell)
    """
  elif command == 'removeDmgrPluginTrace':
    print """
    removeDmgrPluginTrace <no Args>  (assumes to unset the runtime plugin trace to the Dmgr for the Cell)
    """
  else:
    print """
    Supported commands:
    
    generatePlugin <dmgrRoot> <cellName> <nodeName> <webServerName>
    propagatePlugin <dmgrRoot> <cellName> <nodeName> <webServerName>
    setDmgrPluginTrace 
    removeDmgrPluginTrace 
        
    """
  
  sys.exit(1)

#
# Get argument number 'count'; print a usage message if it doesn't exist.
#
def getarg(count,argName):
  if(len(sys.argv) <= count):
    usage("too few arguments; missing "+argName)
  return sys.argv[count].rstrip()

#
# Get argument number 'count'; print a usage message if it doesn't exist.
#
def getoptionalarg(tag, name):
  global optionalArgs
  
  return optionalArgs.get(tag, '')

def getoptionalargs(start):
  args = {}
  
  i = start
  while (i < len(sys.argv)):
    flag = sys.argv[i].strip()
    arg = sys.argv[i+1].strip()
    args[flag] = arg
    i = i + 2
  
  return args

def addOptionalArg(args, arg, argname):
  if not arg == '':
    args.append(argname)
    args.append(arg)

#
# HTTP Server Plugin functions
#

def getCellName():
   return AdminControl.getCell()

def getNodeName():
   return AdminControl.getNode()

def removeDmgrPluginTrace():
    xcellName = getCellName()
    xnodeName = getNodeName()
    xserverName = 'dmgr'
    ts = AdminControl.completeObjectName('type=TraceService,node=%s,process=%s,*' % ( xnodeName, xserverName ,))
    traceString = AdminControl.getAttribute( ts, 'traceSpecification' )
    print traceString
    traceSpec = traceString.replace("com.ibm.websphere.plugincfg.*=all", "")
    print "Setting DMGR Runtime trace spec to %s" % (traceSpec)
    AdminControl.setAttribute(ts, 'traceSpecification', traceSpec)

def setDmgrPluginTrace():
    xcellName = getCellName()
    xnodeName = getNodeName()
    xserverName = 'dmgr'
    ts = AdminControl.completeObjectName('type=TraceService,node=%s,process=%s,*' % ( xnodeName, xserverName ,))
    traceSpec = AdminControl.getAttribute( ts, 'traceSpecification' )
    if traceSpec.find("com.ibm.websphere.plugincfg.*=all") == -1:
      traceSpec = traceSpec + ':' + 'com.ibm.websphere.plugincfg.*=all'
    print "Setting DMGR Runtime trace spec to %s" % (traceSpec)
    AdminControl.setAttribute(ts, 'traceSpecification', traceSpec)
    

def propagatePlugin(dmgrRoot, cellName, nodeName, webServerName):
  mbean = AdminControl.queryNames("WebSphere:*,process=dmgr,type=PluginCfgGenerator")
  args = '[%s/config %s %s %s]' % (dmgrRoot, cellName, nodeName, webServerName)
  result = AdminControl.invoke(mbean, 'propagate', args, '[java.lang.String java.lang.String java.lang.String java.lang.String]')
  AdminConfig.save()
  
  print "Propagated the plugin configuration: %s/config/cells/%s/nodes/%s/servers/%s/plugin-cfg.xml" % (dmgrRoot, cellName, nodeName, webServerName)


def generatePlugin(dmgrRoot, cellName, nodeName, webServerName):
  mbean = AdminControl.queryNames("WebSphere:*,process=dmgr,type=PluginCfgGenerator")
  args = '[%s/config %s %s %s false]' % (dmgrRoot, cellName, nodeName, webServerName)
  result = AdminControl.invoke(mbean, 'generate', args, '[java.lang.String java.lang.String java.lang.String java.lang.String java.lang.Boolean]')
  AdminConfig.save()
  
  print "Generated the plugin configuration: %s/config/cells/%s/nodes/%s/servers/%s/plugin-cfg.xml" % (dmgrRoot, cellName, nodeName, webServerName)

#========================================================================================
#
# Begin main
#
#========================================================================================
if __name__ == '__main__':
  global LOG
  LOG="log"
  command = ''
  command = getarg(0,"command name")
  global optionalArgs

  if (command == 'help'):
    usage('')
  
  elif (command == 'generatePlugin'):
     generatePlugin(
      getarg(1, '<dmgrRoot>'),
      getarg(2, '<cellName>'),
      getarg(3, '<nodeName>'),
      getarg(4, '<webServerName>'))    
  elif (command == 'propagatePlugin'):
    propagatePlugin(
      getarg(1, '<dmgrRoot>'),
      getarg(2, '<cellName>'),
      getarg(3, '<nodeName>'),
      getarg(4, '<webServerName>'))
  elif (command == 'setDmgrPluginTrace'):
    setDmgrPluginTrace()
  elif (command == 'removeDmgrPluginTrace'):
    removeDmgrPluginTrace()
  else:
    usage("'"+command+"' is an unknown command")
